@@ -1,4 +1,4 @@
-/* Time-stamp: <2009-03-25 18:44:10 poser>
+/* Time-stamp: <2009-04-22 13:19:00 poser>
  *
  * Convert text containing various 7-bit ASCII escapes to UTF-8 Unicode.
  *
@@ -599,7 +599,7 @@ int main (int ac, char *av[])
        } /* End of Qfmt case */
        else if( (BYTEO == FType) || (BYTED == FType) || (BYTEH == FType) ) {
 	 Converted=sscanf(iptr,afmt,&b1,&b2,&b3,&NConsumed);
-	 fprintf(stderr,"Converted = %d\n",Converted);fflush(stderr);
+	 /*	 fprintf(stderr,"Converted = %d\n",Converted);fflush(stderr); */
 	 switch(Converted)
 	   {
 	   case 3:
