@@ -1,4 +1,4 @@
-/* Time-stamp: <2009-04-22 00:41:23 poser>
+/* Time-stamp: <2009-08-04 20:34:25 poser>
  *
  * Converts UTF-8 Unicode to pure 7-bit ASCII using any of a number
  * of different representations. 
@@ -518,6 +518,7 @@ int AscifyEquiv(UTF32 c) {
     case 0x2502:
     case 0x2503:
       putchar(0x7C);		/* Vertical line */
+      break;
     case 0x00AB:
     case 0x00BB:
     case 0x201C:
@@ -2904,7 +2905,7 @@ int main (int ac, char *av[])
   /* Combinatorial checks */
 
   if(UseEntitiesP && !(FType == HTMLX || FType == HTMLD || FType == HDML)) {
-    fprintf(stderr,"Use of character entities must be combined with either\ndecimal or hexadecimal HTML character references or HDML hexadecimal character references.\n");
+    fprintf(stderr,"Use of character entities must be combined with either\ndecimal or hexadecimal HTML character references\nor HDML hexadecimal character references.\n");
     exit(BADOPTION);
   }
 
